LCBD_pq: Compute and test local contributions to beta diversity (LCBD)...

View source: R/beta_div_test.R

LCBD_pqR Documentation

Compute and test local contributions to beta diversity (LCBD) of samples

Description

lifecycle-experimental

A wrapper for the adespatial::beta.div() function in the case of physeq object.

Usage

LCBD_pq(physeq, p_adjust_method = "BH", ...)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

p_adjust_method

(chr, default "BH"): the method used to adjust p-value

...

Additional arguments passed on to adespatial::beta.div() function

Value

An object of class beta.div see adespatial::beta.div() function for more information

Author(s)

Adrien Taudière This function is mainly a wrapper of the work of others. Please make a reference to adespatial::beta.div() if you use this function.

See Also

plot_LCBD_pq, adespatial::beta.div()

Examples


if (requireNamespace("adespatial")) {
  data_f <- clean_pq(prune_samples(
    sample_names(data_fungi_sp_known)[1:10],
    data_fungi_sp_known
  ))
  res <- LCBD_pq(data_f, nperm = 5)
  str(res)
  length(res$LCBD)
  length(res$SCBD)
}
if (requireNamespace("adespatial")) {
  LCBD_pq(data_fungi_sp_known, nperm = 5, method = "jaccard")
}



MiscMetabar documentation built on June 8, 2026, 5:07 p.m.