find_vsearch: Find the vsearch binary

View source: R/vsearch.R

find_vsearchR Documentation

Find the vsearch binary

Description

Searches for the vsearch binary in the following order:

  1. The MiscMetabar.vsearchpath option (if set)

  2. A previously installed copy in the MiscMetabar user data directory (via install_vsearch())

  3. The system PATH

Usage

find_vsearch()

Value

A character string with the path to the vsearch binary, or "vsearch" as a fallback (relying on PATH resolution).

Author(s)

Adrien Taudière

See Also

install_vsearch(), is_vsearch_installed()

Examples

find_vsearch()

MiscMetabar documentation built on June 8, 2026, 5:07 p.m.