ggscatt_pq: Scatterplot with marginal distributions and statistical...

ggscatt_pqR Documentation

Scatterplot with marginal distributions and statistical results against Hill diversity of phyloseq object

Description

lifecycle-experimental

Basically a wrapper of function ggstatsplot::ggscatterstats() for object of class phyloseq and Hill number.

Usage

ggscatt_pq(
  physeq,
  num_modality,
  q = c(0, 1, 2),
  rarefy_by_sample = FALSE,
  rngseed = FALSE,
  verbose = TRUE,
  one_plot = TRUE,
  ...
)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

num_modality

(required) Name of the numeric column in physeq@sam_data to plot and test against hill number

q

(a vector of integer) The list of q values to compute the hill number H^q. If Null, no hill number are computed. Default value compute the Hill number 0 (Species richness), the Hill number 1 (exponential of Shannon Index) and the Hill number 2 (inverse of Simpson Index). Hill numbers are more appropriate in DNA metabarcoding studies when q > 0 (Alberdi & Gilbert, 2019; Calderón-Sanou et al., 2019).

rarefy_by_sample

(logical, default FALSE) If TRUE, rarefy samples using phyloseq::rarefy_even_depth() function.

rngseed

(Optional). A single integer value passed to phyloseq::rarefy_even_depth(), which is used to fix a seed for reproducibly random number generation (in this case, reproducibly random subsampling). If set to FALSE, then no fiddling with the RNG seed is performed, and it is up to the user to appropriately call set.seed beforehand to achieve reproducible results. Default is FALSE.

verbose

(logical). If TRUE, print additional information.

one_plot

(logical, default FALSE) If TRUE, return a unique plot with the three plot inside using the patchwork package.

...

Additional arguments passed on to ggstatsplot::ggscatterstats() function.

Details

This function is mainly a wrapper of the work of others. Please make a reference to ggstatsplot::ggscatterstats() if you use this function.

Value

Either an unique ggplot2 (when one_plot is TRUE) or a list of ggplot2 plot for each q.

Author(s)

Adrien Taudière

See Also

ggbetween_pq()

Examples

if (requireNamespace("ggstatsplot")) {
  library("divent")
  ggscatt_pq(data_fungi_mini, "Time", q = 0, type = "non-parametric")
}

if (requireNamespace("ggstatsplot")) {
  ggscatt_pq(data_fungi_mini, "Sample_id",
    q = 0,
    one_plot = FALSE
  )
}


MiscMetabar documentation built on June 8, 2026, 5:07 p.m.