gmpr_pq: Geometric Mean of Pairwise Ratios (GMPR) normalization of a...

View source: R/normalize_pq.R

gmpr_pqR Documentation

Geometric Mean of Pairwise Ratios (GMPR) normalization of a phyloseq object

Description

lifecycle-experimental

Pure-R implementation of the Geometric Mean of Pairwise Ratios normalization (Chen et al. 2018, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7717/peerj.4600")}) tailored for zero-inflated count tables such as microbial OTU tables. Returns counts divided by the per-sample GMPR size factors.

Usage

gmpr_pq(physeq, intersect_no = 4, ct_min = 2)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

intersect_no

(integer, default 4) minimum number of shared taxa between two samples for the pairwise ratio to be computed.

ct_min

(integer, default 2) minimum count for a taxon to be considered "shared" between two samples.

Value

A new phyloseq-class object with a GMPR-normalised otu_table. Size factors are stored as an attribute "gmpr_size_factors" on the otu_table.

Author(s)

Adrien Taudière

References

Chen L. et al. (2018) GMPR: a robust normalization method for zero-inflated count data with application to microbiome sequencing data. PeerJ 6:e4600. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7717/peerj.4600")}

Examples

data_f_gmpr <- gmpr_pq(data_fungi_mini)
sample_sums(data_f_gmpr)

MiscMetabar documentation built on June 8, 2026, 5:07 p.m.