View source: R/alpha_div_test.R
| hill_test_rarperm_pq | R Documentation |
This reduce the risk of a random drawing of a exceptional situation of an unique rarefaction.
hill_test_rarperm_pq(
physeq,
fact,
q = c(0, 1, 2),
nperm = 99,
sample.size = min(sample_sums(physeq)),
verbose = FALSE,
progress_bar = TRUE,
p_val_signif = 0.05,
type = "nonparametric",
...
)
physeq |
(required) a |
fact |
(required) Name of the factor in |
q |
(a vector of integer) The list of q values to compute
the hill number H^q. If Null, no hill number are computed. Default value
compute the Hill number 0 (Species richness), the Hill number 1
(exponential of Shannon Index) and the Hill number 2 (inverse of Simpson
Index). Hill numbers are more appropriate in DNA metabarcoding studies
when |
nperm |
(int) The number of permutations to perform. |
sample.size |
(int) A single integer value equal to the number of
reads being simulated, also known as the depth. See
|
verbose |
(logical). If TRUE, print additional information. |
progress_bar |
(logical, default TRUE) Do we print progress during the calculation? |
p_val_signif |
(float, |
type |
A character specifying the type of statistical approach
(See
|
... |
Additional arguments passed on to |
A list of 6 components :
method
expressions
plots
pvals
prop_signif
statistics
Adrien Taudière
Alberdi, A., & Gilbert, M. T. P. (2019). A guide to the application of Hill numbers to DNA-based diversity analyses. Molecular Ecology Resources. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/1755-0998.13014")}
Calderón-Sanou, I., Münkemüller, T., Boyer, F., Zinger, L., & Thuiller, W. (2019). From environmental DNA sequences to ecological conclusions: How strong is the influence of methodological choices? Journal of Biogeography, 47. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/jbi.13681")}
ggstatsplot::ggbetweenstats(), hill_pq()
## Not run:
if (requireNamespace("ggstatsplot")) {
hill_test_rarperm_pq(data_fungi, "Time", nperm = 3)
res <- hill_test_rarperm_pq(data_fungi, "Height",
nperm = 3,
p_val_signif = 0.9
)
patchwork::wrap_plots(res$plots[[1]])
res$plots[[1]][[1]] + res$plots[[2]][[1]] + res$plots[[3]][[1]]
res$prop_signif
res_para <- hill_test_rarperm_pq(data_fungi, "Height",
nperm = 3,
type = "parametric"
)
res_para$plots[[1]][[1]] + res_para$plots[[2]][[1]] + res_para$plots[[3]][[1]]
res_para$pvals
res_para$method
res_para$expressions[[1]]
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.