View source: R/alpha_div_test.R
| hill_tuckey_pq | R Documentation |
Note that, by default, this function use a sqrt of the read numbers in the linear model in order to correct for uneven sampling depth.
hill_tuckey_pq(
physeq,
modality,
q = c(0, 1, 2),
hill_scales = lifecycle::deprecated(),
silent = TRUE,
correction_for_sample_size = TRUE,
...
)
physeq |
(required) a |
modality |
(required) the variable to test |
q |
(numeric vector) Hill diversity orders to compute (q values).
Default computes Hill number 0 (species richness), Hill number 1
(exponential of Shannon index) and Hill number 2 (inverse of Simpson
index). Formerly |
hill_scales |
|
silent |
(logical) If TRUE, no message are printing. |
correction_for_sample_size |
(logical, default TRUE) This function use a sqrt of the read numbers in the linear model in order to correct for uneven sampling depth. |
... |
Additional arguments passed to |
A ggplot2 object
Adrien Taudière
Alberdi, A., & Gilbert, M. T. P. (2019). A guide to the application of Hill numbers to DNA-based diversity analyses. Molecular Ecology Resources. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/1755-0998.13014")}
Calderón-Sanou, I., Münkemüller, T., Boyer, F., Zinger, L., & Thuiller, W. (2019). From environmental DNA sequences to ecological conclusions: How strong is the influence of methodological choices? Journal of Biogeography, 47. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/jbi.13681")}
data_f <- prune_samples(
sample_names(data_fungi_mini)[1:20],
data_fungi_mini
)
hill_tuckey_pq(data_f, "Height")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.