| is_vsearch_installed | R Documentation |
Useful for testthat and examples compilation for R CMD CHECK and test coverage
is_vsearch_installed(path = find_vsearch())
path |
(default: |
A logical that say if vsearch is install in
Adrien Taudière
find_vsearch(), install_vsearch()
MiscMetabar::is_vsearch_installed()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.