View source: R/beta_div_test.R
| lefser_pq | R Documentation |
Run LEfSe on a phyloseq object
lefser_pq(
physeq,
bifactor = NULL,
modalities = NULL,
compute_relativeAb = TRUE,
by_clade = FALSE,
...
)
physeq |
(required) a |
bifactor |
(required) The name of a column present in the |
modalities |
(default NULL) A vector of modalities to keep in the analysis. If NULL, all modalities present in bifactor are kept. Note that only two modalities are allowed. |
compute_relativeAb |
(logical, default TRUE) Do we compute relative abundance before running LEfSe? |
by_clade |
(logical, default FALSE) Do we use the lefserClades function (which test for different depth in the taxonomic classification) or the lefser function (taxa-level)? |
... |
Additional arguments passed on to |
It is a wrapper of the lefser::lefser() and lefser::lefserClades() functions.
The result of lefser::lefser() or lefser::lefserClades()
Adrien Taudière
if (requireNamespace("lefser") && requireNamespace("mia")) {
res_lefse <- lefser_pq(data_fungi_mini,
bifactor = "Height",
modalities = c("Low", "High")
)
lefser::lefserPlot(res_lefse)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.