Visualization of a collection of couples of samples for comparison
Source:R/plot_functions.R
multi_biplot_pq.RdThis allow to plot all the possible biplot_pq() combination
using one factor.
Arguments
- physeq
(required) a
phyloseq-classobject obtained using thephyloseqpackage.- split_by
(required if pairs is NULL) the name of the factor to make all combination of couples of values
- pairs
(required if split_by is NULL) the name of the factor in physeq@sam_data` slot to make plot by pairs of samples. Each level must be present only two times. Note that if you set pairs, you also must set fact arguments to passed on to
biplot_pq().- na_remove
(logical, default TRUE) if TRUE remove all the samples with NA in the
split_byvariable of thephyseq@sam_dataslot- ...
Other parameters passed on to
biplot_pq()
Examples
# \donttest{
data_fungi_abun <- subset_taxa_pq(data_fungi_mini,
taxa_sums(data_fungi_mini) > 1000)
#> Cleaning suppress 0 taxa ( ) and 0 sample(s) ( ).
#> Number of non-matching ASV 0
#> Number of matching ASV 45
#> Number of filtered-out ASV 0
#> Number of kept ASV 45
#> Number of kept samples 137
p <- multi_biplot_pq(data_fungi_abun, "Height")
#> 47 were discarded due to NA in variables present in formula.
#> Cleaning suppress 5 taxa and 0 samples.
#> Scale for y is already present.
#> Adding another scale for y, which will replace the existing scale.
#> Cleaning suppress 4 taxa and 0 samples.
#> Scale for y is already present.
#> Adding another scale for y, which will replace the existing scale.
#> Cleaning suppress 7 taxa and 0 samples.
#> Scale for y is already present.
#> Adding another scale for y, which will replace the existing scale.
lapply(p, print)
#> $`High-Low`
#>
#> $`High-Middle`
#>
#> $`Low-Middle`
#>
# }