profile_hill_pq: Hill diversity profile for a phyloseq object

View source: R/hill_divent.R

profile_hill_pqR Documentation

Hill diversity profile for a phyloseq object

Description

lifecycle-experimental

Wraps divent::profile_hill() to compute a Hill diversity profile across diversity orders for each sample in a phyloseq object, and returns a ggplot2 object via ggplot2::autoplot().

Usage

profile_hill_pq(physeq, orders = seq(0, 2, 0.1), merge_sample_by = NULL, ...)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

orders

(numeric vector) Hill diversity orders to compute. Default seq(0, 2, 0.1).

merge_sample_by

(character or NULL) If not NULL, merge samples using merge_samples2() before computing profiles.

...

Additional arguments passed to divent::profile_hill().

Value

A ggplot2 object.

See Also

divent::profile_hill(), hill_curves_pq()

Examples


profile_hill_pq(
  prune_samples(sample_names(data_fungi_mini)[1:5], data_fungi_mini),
  orders = c(0, 1, 2)
)


MiscMetabar documentation built on June 8, 2026, 5:07 p.m.