| swarm_clustering | R Documentation |
physeq
or cluster a list of DNA sequences using SWARMA wrapper of SWARM software.
swarm_clustering(
physeq = NULL,
dna_seq = NULL,
d = 1,
swarmpath = "swarm",
vsearch_path = find_vsearch(),
nproc = 1,
fastidious = TRUE,
swarm_args = "",
tax_adjust = 0,
rank_propagation = FALSE,
return_swarm_df = FALSE,
keep_temporary_files = FALSE
)
physeq |
(required) a |
dna_seq |
NOT WORKING FOR THE MOMENT
You may directly use a character vector of DNA sequences
in place of physeq args. When physeq is set, dna sequences take the value of
|
d |
(default: 1) maximum number of differences allowed between two
amplicons, meaning that two amplicons will be grouped if they have |
swarmpath |
(default: swarm) path to swarm |
vsearch_path |
(default: vsearch) path to vsearch, used only if physeq is NULL and dna_seq is provided. |
nproc |
(default: 1) Set to number of cpus/processors to use for the clustering |
fastidious |
(logical, default TRUE), perform a second clustering pass to reduce the number of small clusters (recommended option by swarm authors). Not that if d is different from 1, fastidious is automatically set to FALSE. |
swarm_args |
a one length character element defining other parameters to passed on to swarm (e.g. "–mismatch-penalty 4"). See other possible methods in the SWARM pdf manual |
tax_adjust |
(Default 0) See the man page
of |
rank_propagation |
(logical, default FALSE). Do we propagate the
NA value from lower taxonomic rank to upper rank?
See the man page of |
return_swarm_df |
(logical, default FALSE) Do we return the swarm dataframe instead of the phyloseq object ? Default FALSE return a phyloseq object if physeq is provided. |
keep_temporary_files |
(logical, default: FALSE) Do we keep temporary files ?
|
This function use the merge_taxa_vec function to
merge taxa into clusters. By default tax_adjust = 0 and rank_propagation = FALSE.
See the man page of merge_taxa_vec().
This function is mainly a wrapper of the work of others. Please cite SWARM.
A new object of class physeq or a list of cluster if dna_seq
args was used or if return_swarm_df was set to TRUE.
SWARM can be downloaded from https://github.com/torognes/swarm/.
SWARM can be downloaded from https://github.com/torognes/swarm. More information in the associated publications \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.1093/bioinformatics/btab493")} and \Sexpr[results=rd]{tools:::Rd_expr_doi("doi:10.7717/peerj.593")}
postcluster_pq(), vsearch_clustering()
summary_plot_pq(data_fungi)
system2("swarm", "-h")
data_fungi_swarm <- swarm_clustering(data_fungi)
summary_plot_pq(data_fungi_swarm)
sequences_ex <- c(
"TACCTATGTTGCCTTGGCGGCTAAACCTACCCGGGATTTGATGGGGCGAATTAATAACGAATTCATTGAATCA",
"TACCTATGTTGCCTTGGCGGCTAAACCTACCCGGGATTTGATGGGGCGAATTACCTGGTAAGGCCCACTT",
"TACCTATGTTGCCTTGGCGGCTAAACCTACCCGGGATTTGATGGGGCGAATTACCTGGTAGAGGTG",
"TACCTATGTTGCCTTGGCGGCTAAACCTACC",
"CGGGATTTGATGGCGAATTACCTGGTATTTTAGCCCACTTACCCGGTACCATGAGGTG",
"GCGGCTAAACCTACCCGGGATTTGATGGCGAATTACCTGG",
"GCGGCTAAACCTACCCGGGATTTGATGGCGAATTACAAAG",
"GCGGCTAAACCTACCCGGGATTTGATGGCGAATTACAAAG",
"GCGGCTAAACCTACCCGGGATTTGATGGCGAATTACAAAG"
)
sequences_ex_swarm <- swarm_clustering(
dna_seq = sequences_ex
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.