taxa_as_columns: Force taxa to be in columns in the otu_table of a physeq...

View source: R/dada_phyloseq.R

taxa_as_columnsR Documentation

Force taxa to be in columns in the otu_table of a physeq object

Description

lifecycle-maturing

Mainly for internal use. It is a special case of clean_pq function.

Usage

taxa_as_columns(physeq)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

Value

A new phyloseq-class object

Author(s)

Adrien Taudière

Examples

taxa_as_columns(data_fungi_mini)

MiscMetabar documentation built on June 8, 2026, 5:07 p.m.