track_wkflow_samples: Track the number of reads (= sequences), samples and cluster...

View source: R/dada_phyloseq.R

track_wkflow_samplesR Documentation

Track the number of reads (= sequences), samples and cluster (e.g. ASV) for each sample

Description

lifecycle-experimental

Accept all input types supported by track_wkflow(): phyloseq objects, matrices (samples x clusters), dada-class, derep-class, lists of dada-class or derep-class, and character vectors of fastq/fastq.gz file paths. More information are available in the manual of the function track_wkflow()

Usage

track_wkflow_samples(list_of_objects, output_data_frame = FALSE, ...)

Arguments

list_of_objects

(required) a list of objects passed on to track_wkflow(). Accepts phyloseq, matrix, dada-class, derep-class, lists of dada-class or derep-class, and character vectors of file paths.

output_data_frame

(logical, default FALSE) If TRUE, the function returns a data frame with the number of sequences, clusters and samples for each sample.

...

Other args passed on to track_wkflow()

Value

A list of dataframe. cf track_wkflow() for more information

Author(s)

Adrien Taudière

Examples


tree_A10_005 <- subset_samples(data_fungi, Tree_name == "A10-005")
if (requireNamespace("pbapply")) {
  track_wkflow_samples(tree_A10_005)
}


MiscMetabar documentation built on June 8, 2026, 5:07 p.m.