verify_pq: Verify the validity of a phyloseq object

View source: R/dada_phyloseq.R

verify_pqR Documentation

Verify the validity of a phyloseq object

Description

lifecycle-maturing

Mostly for internal use in MiscMetabar functions.

Usage

verify_pq(
  physeq,
  verbose = FALSE,
  min_nb_seq_sample = 500,
  min_nb_seq_taxa = 1,
  check_taxonomy = FALSE,
  ...
)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

verbose

(logical, default FALSE) If TRUE, prompt some warnings.

min_nb_seq_sample

(numeric) Only used if verbose = TRUE. Minimum number of sequences per samples to not show warning.

min_nb_seq_taxa

(numeric) Only used if verbose = TRUE. Minimum number of sequences per taxa to not show warning.

check_taxonomy

(logical, default FALSE) If TRUE, call verify_tax_table() to check for common taxonomy table issues.

...

Additional arguments passed to verify_tax_table() when check_taxonomy = TRUE.

Value

Nothing if the phyloseq object is valid. An error in the other case. Warnings if verbose = TRUE or check_taxonomy = TRUE

Author(s)

Adrien Taudière

Examples


verify_pq(data_fungi_mini)

verify_pq(data_fungi_mini, check_taxonomy = TRUE)


MiscMetabar documentation built on June 8, 2026, 5:07 p.m.