View source: R/beta_div_test.R
| aldex_pq | R Documentation |
Run Aldex on a phyloseq object
aldex_pq(physeq, bifactor = NULL, modalities = NULL, gamma = 0.5, ...)
physeq |
(required) a |
bifactor |
(required) The name of a column present in the |
modalities |
(default NULL) A vector of modalities to keep in the analysis. If NULL, all modalities present in bifactor are kept. Note that only two modalities are allowed. |
gamma |
(default 0.5) The value of the Dirichlet Monte-Carlo sampling parameter. |
... |
Additional arguments passed on to |
It is a wrapper of the ALDEx2::aldex() function with default gamma=0.5.
The result of ALDEx2::aldex()
Adrien Taudière
if (requireNamespace("ALDEx2")) {
res_aldex <- aldex_pq(data_fungi_mini,
bifactor = "Height",
modalities = c("Low", "High")
)
ALDEx2::aldex.plot(res_aldex, type = "volcano")
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.