| chimera_removal_vs | R Documentation |
Use the VSEARCH software.
chimera_removal_vs(object, type = "Discard_only_chim", clean_pq = FALSE, ...)
object |
(required) A phyloseq-class object or one of dada, derep,
data.frame or list coercible to sequences table using the
function |
type |
(default "Discard_only_chim"). The type define the type of filtering.
|
clean_pq |
(logical; default FALSE) If TRUE, return the phyloseq object
after cleaning using the default parameter of |
... |
Additional arguments passed on to |
This function is mainly a wrapper of the work of others. Please cite vsearch.
I/ a sequences tables if object is of class dada, derep, data.frame or list.
II/ a phyloseq object without (or with if type = 'Select_only_chim') chimeric taxa
Adrien Taudière
chimera_detection_vs(), dada2::removeBimeraDenovo()
data_fungi_nochim <- chimera_removal_vs(data_fungi)
## Not run:
# Adding a chimeric sequence for the example
data_fungi_with_chim <- data_fungi
data_fungi_with_chim@refseq["ASV1710"] <- Biostrings::xscat(
Biostrings::subseq(data_fungi_with_chim@refseq[1], start = 1, end = 150),
Biostrings::subseq(data_fungi_with_chim@refseq[4], start = 151, end = 300)
)
data_fungi_nochim <- chimera_removal_vs(data_fungi)
# Higher value of abskew parameter is less stringent
data_fungi_nochim_16 <- chimera_removal_vs(data_fungi,
abskew = 16, min_seq_length = 10
)
# Potential Chimeric ASVs detected by vsearch
chim_asv <- taxa_names(data_fungi_with_chim)[!taxa_names(data_fungi_with_chim)
%in% taxa_names(data_fungi_nochim)]
"ASV1710" %in% chim_asv
track_wkflow(list(data_fungi_with_chim, data_fungi_nochim))
data_fungi_nochim2 <-
chimera_removal_vs(data_fungi, type = "Select_only_non_chim_seqlen_filtered")
data_fungi_chimera <-
chimera_removal_vs(data_fungi, type = "Select_only_chim")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.