View source: R/dada_phyloseq.R
| clean_pq | R Documentation |
In addition, this function check for discrepancy (and rename) between (i) taxa names in refseq, taxonomy table and otu_table and between (ii) sample names in sam_data and otu_table.
clean_pq(
physeq,
remove_empty_samples = TRUE,
remove_empty_taxa = TRUE,
clean_samples_names = TRUE,
silent = FALSE,
verbose = FALSE,
force_taxa_as_columns = FALSE,
force_taxa_as_rows = FALSE,
reorder_taxa = FALSE,
rename_taxa = FALSE,
simplify_taxo = FALSE,
prefix_taxa_names = "_Taxa",
check_taxonomy = FALSE,
tax_remove_border_spaces = FALSE,
tax_remove_all_space = FALSE,
tax_replace_to_NA = FALSE,
tax_redundant_suffix = FALSE,
tax_replace_space_with = "_",
tax_replace_invisible_chars = FALSE
)
physeq |
(required) a |
remove_empty_samples |
(logical) Do you want to remove samples without sequences (this is done after removing empty taxa) |
remove_empty_taxa |
(logical) Do you want to remove taxa without sequences (this is done before removing empty samples) |
clean_samples_names |
(logical) Do you want to clean samples names? |
silent |
(logical) If true, no message are printing. |
verbose |
(logical) Additional informations in the message the verbose parameter overwrite the silent parameter. |
force_taxa_as_columns |
(logical) If true, if the taxa are rows transpose the otu_table and set taxa_are_rows to false |
force_taxa_as_rows |
(logical) If true, if the taxa are columns transpose the otu_table and set taxa_are_rows to true |
reorder_taxa |
(logical) if TRUE the otu_table is ordered by the number of sequences of taxa (ASV, OTU) in descending order. Default to FALSE. |
rename_taxa |
(logical, default FALSE) if TRUE, taxa (ASV, OTU) are renamed by their position in the OTU_table and prefix_taxa_names param (Taxa_1, Taxa_2, ...). Default to FALSE. If rename taxa (ASV, OTU) is true, the taxa (ASV, OTU) names in verbose information can be misleading. |
simplify_taxo |
(logical) if TRUE, correct the taxonomy_table using the
|
prefix_taxa_names |
(default "Taxa_"): the prefix of taxa names (eg. "ASV_" or "OTU_") |
check_taxonomy |
(logical, default FALSE) If TRUE, call
|
tax_remove_border_spaces |
(logical, default FALSE) If TRUE, trim
leading/trailing whitespace from values in the |
tax_remove_all_space |
(logical, default FALSE) If TRUE, replace
internal whitespace (ASCII or Unicode separator) in |
tax_replace_to_NA |
(logical or character, default FALSE) If TRUE,
replace |
tax_redundant_suffix |
(logical or character, default FALSE) If TRUE,
replace redundant |
tax_replace_space_with |
(character, default |
tax_replace_invisible_chars |
(logical, default FALSE) If TRUE,
strip invisible / unusual characters (control chars, zero-width space,
NBSP inside values, ...) from |
A new phyloseq-class object
Adrien Taudière
clean_pq(data_fungi_mini)
# Trim leading/trailing whitespace in tax_table values
clean_pq(data_fungi_mini, tax_remove_border_spaces = TRUE)
# Replace NA-like values (e.g. "unidentified", "NA") with NA
clean_pq(data_fungi_mini, tax_replace_to_NA = TRUE)
# Drop redundant "_sp" tips
clean_pq(data_fungi_mini, tax_redundant_suffix = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.