| divent_hill_matrix_pq | R Documentation |
Iterates over all samples in an OTU table and computes Hill diversity
numbers using divent::div_hill().
divent_hill_matrix_pq(comm, q, ...)
comm |
(data.frame or matrix) OTU table with samples as rows and taxa as columns. |
q |
(numeric vector) Hill diversity orders to compute. Hill numbers are
more appropriate in DNA metabarcoding studies when |
... |
Additional arguments passed to |
A data.frame with one row per sample and one column per value in
q. Column names are the string representation of the q values.
Row names match the input row names.
Alberdi, A., & Gilbert, M. T. P. (2019). A guide to the application of Hill numbers to DNA-based diversity analyses. Molecular Ecology Resources. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/1755-0998.13014")}
Calderón-Sanou, I., Münkemüller, T., Boyer, F., Zinger, L., & Thuiller, W. (2019). From environmental DNA sequences to ecological conclusions: How strong is the influence of methodological choices? Journal of Biogeography, 47. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1111/jbi.13681")}
divent::div_hill(), hill_pq(), hill_tuckey_pq()
data("data_fungi_mini", package = "MiscMetabar")
data_f <- prune_samples(
sample_names(data_fungi_mini)[1:5],
data_fungi_mini
)
otu <- as.data.frame(phyloseq::otu_table(
taxa_as_columns(data_f)
))
divent_hill_matrix_pq(otu, q = c(0, 1, 2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.