Skip to contents

Searches for the vsearch binary in the following order:

  1. The MiscMetabar.vsearchpath option (if set)

  2. A previously installed copy in the MiscMetabar user data directory (via install_vsearch())

  3. The system PATH

Usage

find_vsearch()

Value

A character string with the path to the vsearch binary, or "vsearch" as a fallback (relying on PATH resolution).

Author

Adrien Taudière

Examples

find_vsearch()
#> [1] "vsearch"