Searches for the vsearch binary in the following order:
The
MiscMetabar.vsearchpathoption (if set)A previously installed copy in the MiscMetabar user data directory (via
install_vsearch())The system PATH
Value
A character string with the path to the vsearch binary, or
"vsearch" as a fallback (relying on PATH resolution).