| find_vsearch | R Documentation |
Searches for the vsearch binary in the following order:
The MiscMetabar.vsearchpath option (if set)
A previously installed copy in the MiscMetabar user data directory
(via install_vsearch())
The system PATH
find_vsearch()
A character string with the path to the vsearch binary, or
"vsearch" as a fallback (relying on PATH resolution).
Adrien Taudière
install_vsearch(), is_vsearch_installed()
find_vsearch()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.