| gmpr_pq | R Documentation |
Pure-R implementation of the Geometric Mean of Pairwise Ratios normalization (Chen et al. 2018, \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7717/peerj.4600")}) tailored for zero-inflated count tables such as microbial OTU tables. Returns counts divided by the per-sample GMPR size factors.
gmpr_pq(physeq, intersect_no = 4, ct_min = 2)
physeq |
(required) a |
intersect_no |
(integer, default 4) minimum number of shared taxa between two samples for the pairwise ratio to be computed. |
ct_min |
(integer, default 2) minimum count for a taxon to be considered "shared" between two samples. |
A new phyloseq-class object with a
GMPR-normalised otu_table. Size factors are stored as an attribute
"gmpr_size_factors" on the otu_table.
Adrien Taudière
Chen L. et al. (2018) GMPR: a robust normalization method for zero-inflated count data with application to microbiome sequencing data. PeerJ 6:e4600. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.7717/peerj.4600")}
data_f_gmpr <- gmpr_pq(data_fungi_mini)
sample_sums(data_f_gmpr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.