| mmseqs2_clustering | R Documentation |
A wrapper of the MMseqs2
easy-cluster or easy-linclust workflow.
mmseqs2_clustering(
physeq = NULL,
dna_seq = NULL,
nproc = 1,
id = 0.97,
mmseqs2path = find_mmseqs2(),
tax_adjust = 0,
rank_propagation = FALSE,
mmseqs2_cluster_method = c("easy-cluster", "easy-linclust"),
coverage = 0.8,
cov_mode = 0,
cluster_mode = 0,
mmseqs2_args = "",
keep_temporary_files = FALSE
)
physeq |
(required) a |
dna_seq |
You may directly use a character vector of DNA sequences
in place of physeq args. When physeq is set, dna sequences take the
value of |
nproc |
(default: 1) Number of threads. |
id |
(default: 0.97) Minimum sequence identity threshold (0–1). |
mmseqs2path |
Path to the |
tax_adjust |
(Default 0) See the man page
of |
rank_propagation |
(logical, default FALSE). Do we propagate the
NA value from lower taxonomic rank to upper rank?
See the man page of |
mmseqs2_cluster_method |
(default: |
coverage |
(numeric, default: 0.8) Alignment coverage threshold
(0–1), passed to |
cov_mode |
(integer, default: 0) Coverage mode:
|
cluster_mode |
(integer, default: 0) Clustering algorithm:
|
mmseqs2_args |
(character, default: |
keep_temporary_files |
(logical, default: FALSE) Keep intermediate files for debugging? |
This function is mainly a wrapper of the work of others. Please cite MMseqs2.
A new object of class physeq or a data.frame of cluster
membership if dna_seq was used.
Adrien Taudière
MMseqs2 can be downloaded from https://github.com/soedinglab/MMseqs2. More information in the associated publication \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1038/nbt.3988")}.
postcluster_pq(), vsearch_clustering(), swarm_clustering()
d_mm <- mmseqs2_clustering(data_fungi_mini)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.