| plot_refseq_extremity_pq | R Documentation |
It is a useful function to check for the absence of unwanted patterns caused for example by Illumina adaptator or bad removal of primers.
If hill_scale is not null, Hill diversity number are used to represent the distribution
of the diversity (equitability) along the sequences.
plot_refseq_extremity_pq(
physeq,
first_n = 10,
last_n = 10,
q = c(1, 2),
min_width = 0
)
physeq |
(required) a |
first_n |
(int, default 10) The number of nucleotides to plot the 5' extremity. |
last_n |
(int, default 10) The number of nucleotides to plot the 3' extremity. |
q |
(vector) A vector defining the Hill number wanted. Set to NULL if
you don't want to plot Hill diversity metrics. Hill numbers are more
appropriate in DNA metabarcoding studies when |
min_width |
(int, default 0) Select only the sequences from physeq@refseq with using a
minimum length threshold. If |
A list of 4 objects
p_start and p_last are the ggplot object representing respectively the start and the end of the sequences.
df_start and df_last are the data.frame corresponding to the ggplot object.
Adrien Taudière
data_f <- prune_samples(
sample_names(data_fungi_mini)[1:20],
data_fungi_mini
)
library("divent")
res1 <- plot_refseq_extremity_pq(data_f, q = 1)
names(res1)
res1$plot_start
res1$plot_last
res2 <- plot_refseq_extremity_pq(data_f, first_n = 200, last_n = 100)
res2$plot_start
res2$plot_last
plot_refseq_extremity_pq(data_f,
first_n = NULL,
last_n = 200,
min_width = 200,
q = c(3)
)$plot_last
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.