Skip to contents

lifecycle-experimental

Wraps divent::profile_hill() to compute a Hill diversity profile across diversity orders for each sample in a phyloseq object, and returns a ggplot2 object via ggplot2::autoplot().

Usage

profile_hill_pq(physeq, orders = seq(0, 2, 0.1), merge_sample_by = NULL, ...)

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

orders

(numeric vector) Hill diversity orders to compute. Default seq(0, 2, 0.1).

merge_sample_by

(character or NULL) If not NULL, merge samples using merge_samples2() before computing profiles.

...

Additional arguments passed to divent::profile_hill().

Value

A ggplot2 object.

Examples

# \donttest{
profile_hill_pq(
  prune_samples(sample_names(data_fungi_mini)[1:5], data_fungi_mini),
  orders = c(0, 1, 2)
)
#> Taxa are now in columns.

# }