View source: R/dada_phyloseq.R
| track_wkflow_samples | R Documentation |
Accept all input types supported by track_wkflow(): phyloseq objects,
matrices (samples x clusters), dada-class, derep-class, lists of
dada-class or derep-class, and character vectors of fastq/fastq.gz file
paths.
More information are available in the manual of the function track_wkflow()
track_wkflow_samples(list_of_objects, output_data_frame = FALSE, ...)
list_of_objects |
(required) a list of objects passed on to
|
output_data_frame |
(logical, default FALSE) If TRUE, the function returns a data frame with the number of sequences, clusters and samples for each sample. |
... |
Other args passed on to |
A list of dataframe. cf track_wkflow() for more information
Adrien Taudière
tree_A10_005 <- subset_samples(data_fungi, Tree_name == "A10-005")
if (requireNamespace("pbapply")) {
track_wkflow_samples(tree_A10_005)
}
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.