View source: R/dada_phyloseq.R
| verify_pq | R Documentation |
Mostly for internal use in MiscMetabar functions.
verify_pq(
physeq,
verbose = FALSE,
min_nb_seq_sample = 500,
min_nb_seq_taxa = 1,
check_taxonomy = FALSE,
...
)
physeq |
(required) a |
verbose |
(logical, default FALSE) If TRUE, prompt some warnings. |
min_nb_seq_sample |
(numeric) Only used if verbose = TRUE. Minimum number of sequences per samples to not show warning. |
min_nb_seq_taxa |
(numeric) Only used if verbose = TRUE. Minimum number of sequences per taxa to not show warning. |
check_taxonomy |
(logical, default FALSE) If TRUE, call
|
... |
Additional arguments passed to |
Nothing if the phyloseq object is valid. An error in the other case. Warnings if verbose = TRUE or check_taxonomy = TRUE
Adrien Taudière
verify_pq(data_fungi_mini)
verify_pq(data_fungi_mini, check_taxonomy = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.