Skip to contents

lifecycle-experimental

Wrapper around DESeq2::varianceStabilizingTransformation() (Love, Huber & Anders 2014, doi:10.1186/s13059-014-0550-8 ). Counts are incremented by 1 to handle zeros before VST is applied.

Usage

vst_pq(physeq, blind = TRUE, fitType = "parametric")

Arguments

physeq

(required) a phyloseq-class object obtained using the phyloseq package.

blind

(logical, default TRUE) passed to DESeq2.

fitType

(character, default "parametric") passed to DESeq2.

Value

A new phyloseq-class object with a VST transformed otu_table.

Author

Adrien Taudière

Examples

data_f_vst <- vst_pq(data_fungi_mini)
#> converting counts to integer mode
#> -- note: fitType='parametric', but the dispersion trend was not well captured by the
#>    function: y = a/x + b, and a local regression fit was automatically substituted.
#>    specify fitType='local' or 'mean' to avoid this message next time.