Variance Stabilizing Transformation of a phyloseq object (DESeq2)
Source:R/normalize_pq.R
vst_pq.RdWrapper around DESeq2::varianceStabilizingTransformation()
(Love, Huber & Anders 2014, doi:10.1186/s13059-014-0550-8
). Counts
are incremented by 1 to handle zeros before VST is applied.
Arguments
- physeq
(required) a
phyloseq-classobject obtained using thephyloseqpackage.- blind
(logical, default
TRUE) passed to DESeq2.- fitType
(character, default
"parametric") passed to DESeq2.
Value
A new phyloseq-class object with a VST
transformed otu_table.
Examples
data_f_vst <- vst_pq(data_fungi_mini)
#> converting counts to integer mode
#> -- note: fitType='parametric', but the dispersion trend was not well captured by the
#> function: y = a/x + b, and a local regression fit was automatically substituted.
#> specify fitType='local' or 'mean' to avoid this message next time.